==> tinydantic-0.1.0.tar.gz: tinydantic-0.1.0/LICENSE.md <==
# License

Copyright © Chris Wilson and contributors.

Code, including source files and any code samples in the content, is
dual-licensed under either the [MIT](https://opensource.org/license/mit/) or the
[Apache 2.0](https://www.apache.org/licenses/LICENSE-2.0) license. This means
you can use the code in your own projects under either license of your choosing.

All other content (e.g. documentation and images) is licensed under the [CC-BY-4.0](https://creativecommons.org/licenses/by/4.0/) license. This gives you permission to use the content for almost any purpose (but does not grant you any trademark permissions), so long as you note the license and give credit (see [Best practices for attribution](https://wiki.creativecommons.org/wiki/Best_practices_for_attribution) for examples).

When you contribute to this repository you are doing so under the above
licenses, without any additional terms or conditions.

*The text above is adapted from
https://github.com/github/opensource.guide/blob/main/notices.md#licenses used
under the [CC-BY-4.0](https://creativecommons.org/licenses/by/4.0/) license.*

## SPDX & REUSE Compliance

 [![REUSE
 status](https://api.reuse.software/badge/github.com/cdwilson/tinydantic)](https://api.reuse.software/info/github.com/cdwilson/tinydantic)

This repository is compliant with version 3.2 of the [REUSE
Specification](https://reuse.software/spec/).

License files are contained in the [LICENSES/](LICENSES/) directory and
additional copyright & license information can be found in
[REUSE.toml](REUSE.toml).

Install the [reuse tool](https://github.com/fsfe/reuse-tool) and run the
following commands for detailed copyright & license information on individual
files:

```sh
reuse spdx
```

==> tinydantic-0.1.8.tar.gz: tinydantic-0.1.8/LICENSE.md <==
# License

Copyright © Chris Wilson and contributors.

Code, including source files and any code samples in the content, is
dual-licensed under either the [MIT](https://opensource.org/license/mit/) or the
[Apache 2.0](https://www.apache.org/licenses/LICENSE-2.0) license. This means
you can use the code in your own projects under either license of your choosing.

All other content (e.g. documentation and images) is licensed under the [CC-BY-4.0](https://creativecommons.org/licenses/by/4.0/) license. This gives you permission to use the content for almost any purpose (but does not grant you any trademark permissions), so long as you note the license and give credit (see [Best practices for attribution](https://wiki.creativecommons.org/wiki/Best_practices_for_attribution) for examples).

When you contribute to this repository you are doing so under the above
licenses, without any additional terms or conditions.

*The text above is adapted from
https://github.com/github/opensource.guide/blob/main/notices.md#licenses used
under the [CC-BY-4.0](https://creativecommons.org/licenses/by/4.0/) license.*

## SPDX & REUSE Compliance

 [![REUSE
 status](https://api.reuse.software/badge/github.com/tinydantic/tinydantic)](https://api.reuse.software/info/github.com/tinydantic/tinydantic)

This repository is compliant with version 3.2 of the [REUSE
Specification](https://reuse.software/spec/).

License files are contained in the [LICENSES/](LICENSES/) directory and
additional copyright & license information can be found in
[REUSE.toml](REUSE.toml).

Install the [reuse tool](https://github.com/fsfe/reuse-tool) and run the
following commands for detailed copyright & license information on individual
files:

```sh
reuse spdx
```
